==> appmesh-1.93.0-sources.jar: software/amazon/awscdk/services/appmesh/VirtualRouterListener.java <==
package software.amazon.awscdk.services.appmesh;

/**
 * (experimental) Represents the properties needed to define listeners for a VirtualRouter.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:47:05.109Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.appmesh.$Module.class, fqn = "@aws-cdk/aws-appmesh.VirtualRouterListener")
public abstract class VirtualRouterListener extends software.amazon.jsii.JsiiObject {

    protected VirtualRouterListener(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected VirtualRouterListener(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    protected VirtualRouterListener() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * (experimental) Returns a GRPC Listener for a VirtualRouter.
     * <p>
     * @param port the optional port of the listener, 8080 by default.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListener grpc(final @org.jetbrains.annotations.Nullable java.lang.Number port) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class, "grpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class), new Object[] { port });
    }

    /**
     * (experimental) Returns a GRPC Listener for a VirtualRouter.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListener grpc() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class, "grpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class));
    }

    /**
     * (experimental) Returns an HTTP Listener for a VirtualRouter.
     * <p>
     * @param port the optional port of the listener, 8080 by default.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListener http(final @org.jetbrains.annotations.Nullable java.lang.Number port) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class, "http", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class), new Object[] { port });
    }

    /**
     * (experimental) Returns an HTTP Listener for a VirtualRouter.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListener http() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class, "http", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class));
    }

    /**
     * (experimental) Returns an HTTP2 Listener for a VirtualRouter.
     * <p>
     * @param port the optional port of the listener, 8080 by default.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListener http2(final @org.jetbrains.annotations.Nullable java.lang.Number port) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class, "http2", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class), new Object[] { port });
    }

    /**
     * (experimental) Returns an HTTP2 Listener for a VirtualRouter.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListener http2() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class, "http2", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class));
    }

    /**
     * (experimental) Returns a TCP Listener for a VirtualRouter.
     * <p>
     * @param port the optional port of the listener, 8080 by default.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListener tcp(final @org.jetbrains.annotations.Nullable java.lang.Number port) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class, "tcp", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class), new Object[] { port });
    }

    /**
     * (experimental) Returns a TCP Listener for a VirtualRouter.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListener tcp() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class, "tcp", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class));
    }

    /**
     * (experimental) Called when the VirtualRouterListener type is initialized.
     * <p>
     * Can be used to enforce
     * mutual exclusivity
     * <p>
     * @param scope This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public abstract @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListenerConfig bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    private static final class Jsii$Proxy extends software.amazon.awscdk.services.appmesh.VirtualRouterListener {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * (experimental) Called when the VirtualRouterListener type is initialized.
         * <p>
         * Can be used to enforce
         * mutual exclusivity
         * <p>
         * @param scope This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListenerConfig bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope) {
            return software.amazon.jsii.Kernel.call(this, "bind", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListenerConfig.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required") });
        }
    }
}

==> appmesh-1.182.0-sources.jar: software/amazon/awscdk/services/appmesh/VirtualRouterListener.java <==
package software.amazon.awscdk.services.appmesh;

/**
 * Represents the properties needed to define listeners for a VirtualRouter.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Mesh mesh;
 * VirtualRouter router = mesh.addVirtualRouter("router", VirtualRouterBaseProps.builder()
 *         .listeners(List.of(VirtualRouterListener.http(8080)))
 *         .build());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:46.367Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.appmesh.$Module.class, fqn = "@aws-cdk/aws-appmesh.VirtualRouterListener")
public abstract class VirtualRouterListener extends software.amazon.jsii.JsiiObject {

    protected VirtualRouterListener(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected VirtualRouterListener(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected VirtualRouterListener() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Returns a GRPC Listener for a VirtualRouter.
     * <p>
     * @param port the optional port of the listener, 8080 by default.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListener grpc(final @org.jetbrains.annotations.Nullable java.lang.Number port) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class, "grpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class), new Object[] { port });
    }

    /**
     * Returns a GRPC Listener for a VirtualRouter.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListener grpc() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class, "grpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class));
    }

    /**
     * Returns an HTTP Listener for a VirtualRouter.
     * <p>
     * @param port the optional port of the listener, 8080 by default.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListener http(final @org.jetbrains.annotations.Nullable java.lang.Number port) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class, "http", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class), new Object[] { port });
    }

    /**
     * Returns an HTTP Listener for a VirtualRouter.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListener http() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class, "http", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class));
    }

    /**
     * Returns an HTTP2 Listener for a VirtualRouter.
     * <p>
     * @param port the optional port of the listener, 8080 by default.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListener http2(final @org.jetbrains.annotations.Nullable java.lang.Number port) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class, "http2", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class), new Object[] { port });
    }

    /**
     * Returns an HTTP2 Listener for a VirtualRouter.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListener http2() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class, "http2", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class));
    }

    /**
     * Returns a TCP Listener for a VirtualRouter.
     * <p>
     * @param port the optional port of the listener, 8080 by default.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListener tcp(final @org.jetbrains.annotations.Nullable java.lang.Number port) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class, "tcp", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class), new Object[] { port });
    }

    /**
     * Returns a TCP Listener for a VirtualRouter.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListener tcp() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class, "tcp", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListener.class));
    }

    /**
     * Called when the VirtualRouterListener type is initialized.
     * <p>
     * Can be used to enforce
     * mutual exclusivity
     * <p>
     * @param scope This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListenerConfig bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    private static final class Jsii$Proxy extends software.amazon.awscdk.services.appmesh.VirtualRouterListener {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Called when the VirtualRouterListener type is initialized.
         * <p>
         * Can be used to enforce
         * mutual exclusivity
         * <p>
         * @param scope This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.appmesh.VirtualRouterListenerConfig bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope) {
            return software.amazon.jsii.Kernel.call(this, "bind", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.VirtualRouterListenerConfig.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required") });
        }
    }
}
